import logging

import rshanker779_common as utils


@utils.time_it
def example_function():
    return 1


@utils.catch_errors
def error_function():
    raise ValueError


def test_time_it(caplog):
    with caplog.at_level(logging.INFO):
        res = example_function()
    assert res == 1
    assert len(caplog.messages) == 1
    assert "example_function executed in" in caplog.messages[0]


def test_catch_errors(caplog):
    with caplog.at_level(logging.ERROR):
        res = error_function()
    assert res is None
    assert len(caplog.messages) == 1
    assert "Error calling error_function" in caplog.messages[0]



import pathlib

import pytest

import rshanker779_common as utils


@pytest.fixture
def example_function():
    def example_string_function(x, y):
        return str(reversed(x)) + y

    return example_string_function


@pytest.fixture
def profiler(example_function):
    return utils.Profiler(example_function, 100, "xfsjkfljkslf", "fkdskfl")


def test_profiler(profiler):
    profiler.profile()
    assert pathlib.Path(profiler.filename).is_file()



import time
from functools import wraps

from rshanker779_common import get_logger

logger = get_logger(__name__)


def time_it(f):
    @wraps(f)
    def wrapper_func(*args, **kwargs):
        s = time.perf_counter()
        res = f(*args, **kwargs)
        elapsed = time.perf_counter() - s
        logger.info(f"{f.__name__} executed in {elapsed:2f} seconds")
        return res

    return wrapper_func


def catch_errors(f):
    @wraps(f)
    def wrapper_func(*args, **kwargs):
        try:
            return f(*args, **kwargs)
        except Exception:
            logger.exception(f"Error calling {f.__name__}")

    return wrapper_func
